netapp_ontap.models.application_lun_mapping_object API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.application_lun_mapping_object`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ApplicationLunMappingObjectSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ApplicationLunMappingObject object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `fcp GET`

    All possible Fibre Channel Protocol (FCP) access endpoints for the LUN.

  `igroup GET POST PATCH`

    The igroup field of the application_lun_mapping_object.

  `iscsi GET`

    All possible iSCSI access endpoints for the LUN.

  `lun_id GET`

    LUN ID